@@ -66,9 +66,8 @@ public:
     // unnecessary tags Qt inserts
     QString asCleanedHTML() const;
 
-    SignatureConfigurator *q;
-    bool inlinedHtml = false;
     QString imageLocation;
+    SignatureConfigurator *q;
     QCheckBox *mEnableCheck = nullptr;
     QCheckBox *mHtmlCheck = nullptr;
     QComboBox *mSourceCombo = nullptr;
@@ -78,6 +77,7 @@ public:
     KToolBar *mEditToolBar = nullptr;
     KToolBar *mFormatToolBar = nullptr;
     KPIMTextEdit::RichTextComposer *mTextEdit = nullptr;
+    bool inlinedHtml = false;
 };
 //@endcond
 
@@ -471,7 +471,7 @@ void SignatureConfigurator::setImageLocation(const QString &path)
 
 void SignatureConfigurator::setImageLocation(const Identity &identity)
 {
-    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/%1/").arg(
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/emailidentities/%1/").arg(
         QString::number(identity.uoid()));
     QDir().mkpath(dir);
     setImageLocation(dir);
